Validates and executes a list of tool calls returned by the LLM. Each call is a list with at minimum a tool field naming the sdcMicro function, plus the parameters for that function.

execute_tool_calls(sdcObj, calls)

Arguments

sdcObj

An sdcMicroObj.

calls

A list of tool call lists, each with a tool field.

Value

Modified sdcMicroObj.