R/ai_anonymization_utilities.R
execute_tool_calls.RdValidates and executes a list of tool calls returned by the LLM.
Each call is a list with at minimum a tool field naming the
sdcMicro function, plus the parameters for that function.
execute_tool_calls(sdcObj, calls)Modified sdcMicroObj.