Learn R Programming

sdcMicro (version 5.8.1)

execute_tool_calls: Execute structured tool calls on an sdcMicroObj

Description

Validates and executes a list of tool calls returned by the LLM. Each call is a list with at minimum a tool field naming the sdcMicro function, plus the parameters for that function.

Usage

execute_tool_calls(sdcObj, calls)

Value

Modified sdcMicroObj.

Arguments

sdcObj

An sdcMicroObj.

calls

A list of tool call lists, each with a tool field.